"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class Resolver {
    constructor(config, signature) {
        this.config = config;
        this.signature = signature.replace(':', '.');
        this.command = signature;
    }
    resolveParser() {
        return __awaiter(this, void 0, void 0, function* () {
            const configuredParser = this.config.get(`commands.${this.signature}.parser`);
            if (configuredParser == null) {
                throw new Error(`ConfigError:
      No parser configuration could be found for \`${this.command}\`.
      Please check your configuration file, and make sure that a value has been
      defined for \`${this.signature}.parser\`
      `);
            }
            let parserClass;
            try {
                parserClass = yield Promise.resolve().then(() => require(String(configuredParser)));
                parserClass = parserClass.default;
            }
            catch (error) {
                error.message =
                    `Could not find module \`${configuredParser}\`. Run \`npm install ${configuredParser}\` to install`;
                throw error;
            }
            return new parserClass();
        });
    }
    resolveDecorators() {
        return __awaiter(this, void 0, void 0, function* () {
            const configuredDecorators = this.config.get(`commands.${this.signature}.decorators`);
            if (configuredDecorators == null) {
                throw new Error(`ConfigError:
      No resolvable decorator configuration could be found for \`${this.command}\`.
      Please check your configuration file, and make sure that a value has been
      defined for \`${this.signature}.decorators\`
      `);
            }
            if (Array.isArray(configuredDecorators) === false) {
                throw new Error(`ConfigError:
      The decorator configuration for \`${this.command}\` is not a valid array. Please make
      sure your configuration is correct
      `);
            }
            const decoratorClasses = [];
            if (typeof configuredDecorators !== 'string') {
                for (let i = 0; i < configuredDecorators.length; i = i + 1) {
                    const decorator = configuredDecorators[i];
                    try {
                        let decoratorClass = yield Promise.resolve().then(() => require(decorator));
                        decoratorClass = decoratorClass.default;
                        decoratorClasses.push(new decoratorClass());
                    }
                    catch (error) {
                        error.message =
                            `Could not find module \`${decorator}\`. Run \`npm install ${decorator}\` to install`;
                        throw error;
                    }
                }
            }
            return decoratorClasses;
        });
    }
    resolveFactories() {
        return __awaiter(this, void 0, void 0, function* () {
            const configuredFactories = this.config.get(`commands.${this.signature}.factories`);
            if (configuredFactories == null) {
                throw new Error(`ConfigError:
      No resolvable factory configuration could be found for \`${this.command}\`.
      Please check your configuration file, and make sure that a value has been
      defined for \`${this.signature}.factories\`
      `);
            }
            if (Array.isArray(configuredFactories) === false) {
                throw new Error(`ConfigError:
      The factory configuration for \`${this.command}\` is not a valid array. Please make
      sure your configuration is correct
      `);
            }
            const factoryClasses = [];
            if (typeof configuredFactories !== 'string') {
                for (let i = 0; i < configuredFactories.length; i = i + 1) {
                    const factory = configuredFactories[i];
                    try {
                        let factoryClass = yield Promise.resolve().then(() => require(factory));
                        factoryClass = factoryClass.default;
                        factoryClasses.push(new factoryClass());
                    }
                    catch (error) {
                        error.message =
                            `Could not find module \`${factory}\`. Run \`npm install ${factory}\` to install`;
                        throw error;
                    }
                }
            }
            return factoryClasses;
        });
    }
}
exports.default = Resolver;
//# sourceMappingURL=Resolver.js.map